@@ -6,7 +6,7 @@ use strict;
 use CPANPLUS::Dist::Base   qw();
 use Exporter               qw(import);
 
-our $VERSION     = '1.27';
+our $VERSION     = '1.28';
 our @EXPORT      = qw();
 our @EXPORT_OK   = qw(dist_pkgname dist_pkgver);
 our %EXPORT_TAGS = ( 'all' => [ @EXPORT_OK ] );
@@ -695,7 +695,7 @@ sub get_pkgvars
         $vars{'sha512sums'} = $self->_calc_shasum(512);
     }
 
-	$vars{$_} = _specstr($pkglinks->{$_}) for (qw/depends makedepends/);
+    $vars{$_} = _specstr($pkglinks->{$_}) for (qw/depends makedepends/);
     for (qw/checkdepends conflicts/) {
         if (@{$pkglinks->{$_}}) {
             $vars{$_} = _specstr($pkglinks->{$_});
@@ -1744,16 +1744,12 @@ sub _prune_if_blocks
 {
     my ($templ, $templ_vars) = @_;
 
-    while ( my ($varname) = $templ =~ $TT_IF_MATCH ) {
+    while (my ($varname) = $templ =~ $TT_IF_MATCH) {
         croak "Invalid template given.\n"
             . 'Must provide a variable name in an IF block' unless $varname;
 
-        croak "Unknown variable name in IF block: $varname"
-            unless ( exists $templ_vars->{$varname} );
-
-        my @chunks = _extract_nested( $templ, $TT_IF_MATCH, $TT_END_MATCH );
-
-        if ( ! $templ_vars->{$varname} ) { splice @chunks, 1, 1; }
+        my @chunks = _extract_nested($templ, $TT_IF_MATCH, $TT_END_MATCH);
+        unless ($templ_vars->{$varname}) { splice @chunks, 1, 1; }
         $templ = join q{}, @chunks;
     }
 
@@ -1843,10 +1839,7 @@ sub _process_template
     # Fall back on our own primitive little template engine...
     $templ = _prune_if_blocks( $templ, $templ_vars );
     $templ =~ s{ $TT_VAR_MATCH }
-               { ( defined $templ_vars->{$1}
-                   ? $templ_vars->{$1}
-                   : croak "Template variable $1 was not provided" )
-               }xmseg;
+               { (defined $templ_vars->{$1} ? $templ_vars->{$1} : "") }xmseg;
 
     return $templ;
 }
